@@ -1,3 +1,17 @@
+# Copyright (C) 2015 Ryan Fisher, Gary Hemming
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+# 
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import sys
 from dqsegdb import urifunctions
 from dqsegdb import clientutils
@@ -92,18 +106,21 @@ def dqsegdbMaxVersion(protocol,server,ifo,name):
     """
     queryurl=urifunctions.constructFlagQueryURL(protocol,server,ifo)
     try:
-        result=urifunctions.getDataUrllib2(queryurl)
+        result=urifunctions.getDataUrllib2(queryurl,warnings=False)
     except HTTPError as e:
-        if e.code==404:
+        print "e.code: %s  FIX!" % str(e.code)
+        if int(e.code)==404:
             return 0
         else:
+            # Print all the messages this time
+            result=urifunctions.getDataUrllib2(queryurl,warnings=True)
             raise
     # Now parse result for max version:
     queryurl=urifunctions.constructVersionQueryURL(protocol,server,ifo,name)
     try: 
-        result=urifunctions.getDataUrllib2(queryurl)
+        result=urifunctions.getDataUrllib2(queryurl,warnings=False)
     except HTTPError as e:
-        if e.code==404:
+        if int(e.code)==404:
             return 0
         else:
             raise
@@ -295,6 +312,40 @@ def reportFlags(protocol,server,verbose):
     result=urifunctions.getDataUrllib2(queryurl)
     return result
 
+def reportActive(protocol,server,includeSegments,verbose,gps_start_time,gps_end_time):
+    """
+    Construct url and issue query to get the reported list of all active segments for all flags in the time window provided.
+    From the API Doc:
+    Get a JSON string resource containing the active segments for all flags between t1 and t2. Note that this returns exactly what /dq/IFO/FLAG/VERSION does, except for ALL flags over the query period instead of one flag. The clients must assume that they may get empty active lists for flags that are unactive between times t1 and t2.
+
+    Parameters
+    ----------
+    protocol : `string`
+        Ex: 'https'
+    server : `string`
+        Ex: 'dqsegdb5.phy.syr.edu'
+    includeSegments : `boolean`
+        Ex: True
+    verbose : `boolean`
+        Ex: True
+    gps_start_time: `int`
+        Ex: 999999999
+    gps_end_time: `int`
+        Ex: 999999999
+
+    """
+    if includeSegments:
+        includeText=""
+        timeText="?s=%d&e=%d"%(gps_start_time,gps_end_time)
+    else:
+        includeText="?include=metadata"
+        timeText="&s=%d&e=%d"%(gps_start_time,gps_end_time)
+    queryurl=protocol+"://"+server+"/report/active"+includeText+timeText
+    if verbose:
+        print queryurl
+    result=urifunctions.getDataUrllib2(queryurl,timeout=1200)
+    return result,queryurl
+
 def reportKnown(protocol,server,includeSegments,verbose,gps_start_time,gps_end_time):
     """
     Construct url and issue query to get the reported list of all known segments for all flags in the time window provided.
@@ -307,25 +358,20 @@ def reportKnown(protocol,server,includeSegments,verbose,gps_start_time,gps_end_t
         Ex: 'https'
     server : `string`
         Ex: 'dqsegdb5.phy.syr.edu'
-    ifo : `string`
-        Ex: 'L1'
-    name: `string`
-        Ex: 'DMT-SCIENCE'
-    version : `string` or `int`
-        Ex: '1'
-    include_list_string : `string`
-        Ex: "metadata,known,active"
-    startTime : `int`
+    includeSegments : `boolean`
+        Ex: True
+    verbose : `boolean`
+        Ex: True
+    gps_start_time: `int`
         Ex: 999999999
-    endTime : `int`
+    gps_end_time: `int`
         Ex: 999999999
-
     """
-    includeText="?include=metadata"
     if includeSegments:
         includeText=""
         timeText="?s=%d&e=%d"%(gps_start_time,gps_end_time)
     else:
+        includeText="?include=metadata"
         timeText="&s=%d&e=%d"%(gps_start_time,gps_end_time)
     queryurl=protocol+"://"+server+"/report/known"+includeText+timeText
     if verbose:
@@ -348,6 +394,7 @@ def parseKnown(jsonResult):
     #        "end": "1076401264", 
     #        "include": [], 
     #        "server": "dqsegdb5.phy.syr.edu", 
+    #        # Jul 28: api_version replaced server_code_version
     #        "server_code_version": "v1r5", 
     #        "server_elapsed_query_time": 2.3630100000000001, 
     #        "server_timestamp": 1079895401, 
@@ -595,9 +642,7 @@ def patchWithFailCases(i,url,debug=True,inlogger=None,testing_options={}):
             startTime=testing_options['synchronize']
             inlogger.debug("Trying to patch synchronously at time %s" % startTime)
             waitTill(startTime)
-            patchDataUrllib2(url,json.dumps(i.flagDict),logger=inlogger)
-        else:
-            patchDataUrllib2(url,json.dumps(i.flagDict),logger=inlogger)
+        patchDataUrllib2(url,json.dumps(i.flagDict),logger=inlogger)
         if debug:
             inlogger.debug("Patch alone succeeded for %s" % url)
             #print "Patch alone succeeded for %s" % url
@@ -686,6 +731,11 @@ def InsertMultipleDQXMLFileThreaded(filenames,logger,server='http://slwebtest.vi
     else:
         # Older server, so don't want to supply extra comments... 
         new_comments=False
+    if apiResult >= "2.1.15":
+        # Alteration to insertion_metadata from uri to comment to accomodate s6 data conversion
+        use_new_insertion_metadata=True
+    else:
+        use_new_insertion_metadata=False
 
 
     if 'offset' in testing_options:
@@ -763,7 +813,7 @@ def InsertMultipleDQXMLFileThreaded(filenames,logger,server='http://slwebtest.vi
             process_dict[temp_process_id]['process_metadata'] = {}
             if hackDec11:
                 process_dict[temp_process_id]['process_metadata']['process_start_time'] = process_dict[temp_process_id]['start_time']
-            else:
+            else: # This is for the newer server APIs:  (April 24 2015 we checked it (it probably changed before ER6 finally))
                 process_dict[temp_process_id]['process_metadata']['process_start_timestamp'] = process_dict[temp_process_id]['start_time']
             if new_comments:
                 process_dict[temp_process_id]['process_comment']=process_dict[temp_process_id]['comment']
@@ -903,20 +953,24 @@ def InsertMultipleDQXMLFileThreaded(filenames,logger,server='http://slwebtest.vi
                 start = flag_versions[i].temp_process_ids[pid]['insert_data_start']
                 stop = flag_versions[i].temp_process_ids[pid]['insert_data_stop']
                 if new_comments:
-                    flag_versions[i].flag_version_comment=process_dict[pid]['process_comment']  # Fix!!! Test!
+                    flag_versions[i].flag_version_comment=process_dict[pid]['process_comment']  
                 insert_history_dict = {}
                 try:
                     insert_history_dict['process_metadata'] = process_dict[pid]['process_metadata']
                 except:
-                    import pdb
-                    pdb.set_trace()
+                    raise
+                #    import pdb
+                #    pdb.set_trace()
                 insert_history_dict['insertion_metadata'] = {}
                 insert_history_dict['insertion_metadata']['insert_data_stop'] = stop
                 insert_history_dict['insertion_metadata']['insert_data_start'] = start
                 ifo = flag_versions[i].ifo
                 version = flag_versions[i].version
                 name = flag_versions[i].name
-                insert_history_dict['insertion_metadata']['uri'] = '/dq/'+'/'.join([str(ifo),str(name),str(version)])
+                if use_new_insertion_metadata==True:
+                    insert_history_dict['insertion_metadata']['comment'] = '/dq/'+'/'.join([str(ifo),str(name),str(version)])  # FIX make dq a constant string in case we ever change it
+                else:
+                    insert_history_dict['insertion_metadata']['uri'] = '/dq/'+'/'.join([str(ifo),str(name),str(version)])  # FIX make dq a constant string in case we ever change it
                 #print ifo,name,version
                 insert_history_dict['insertion_metadata']['timestamp'] = _UTCToGPS(time.gmtime())
                 insert_history_dict['insertion_metadata']['auth_user']=process.get_username()
