@@ -5,13 +5,13 @@
 """
 
 __author__ = 'Ryan Fisher <ryan.fisher@ligo.org>'
-__version__ = 'ebe222'
-__date__ = '2015-04-30 20:57:55 +0000'
+__version__ = 'dqsegdb-release-1-2-1'
+__date__ = '2015-08-07 20:39:17 +0000'
 
-version = 'ebe222'
-git_id = 'ebe222716a7c488ced8611467b0952816558054b'
-git_branch = 'dqsegdb-1-1-0-branch'
-git_tag = None
+version = 'dqsegdb-release-1-2-1'
+git_id = '4a24710c8954e340ffbb54a3b3c6e7d4e30c175c'
+git_branch = None
+git_tag = 'dqsegdb-release-1-2-1'
 git_author = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_committer = 'Ryan Fisher <ryan.fisher@ligo.org>'
 git_status = 'UNCLEAN: Modified working tree'
